This project aim to facilitate the migration from other ERP to Odoo with EMC application:

 - Add new field to SubscriptionRequest to save the migrated cooperator number.
 - Add a wizard to validate all the SubscriptionRequests in background.
 - Add a wizard to mark as paid all the capital release invoices in background sorted by the migrated cooperator number.

Please don't hesitate to suggest one of your modules to this project.
